summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_html_breakages.py
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2017-06-12 22:43:07 +0200
committerHolger Levsen <holger@layer-acht.org>2017-06-16 16:28:34 +0200
commitfef02237f9f7aef649db16ba4162355f9a4deb2f (patch)
treef6d98b71946ee2544e15b7dfe6202268ffcd6a80 /bin/reproducible_html_breakages.py
parentef7fe352e2bb940ac2495e1f303d5ca7c8385b38 (diff)
downloadjenkins.debian.net-fef02237f9f7aef649db16ba4162355f9a4deb2f.tar.xz
reproducible Debian: WIP for s#testing#stretch#g - see TODO4stretch_rename.txt for status
Signed-off-by: Holger Levsen <holger@layer-acht.org>
Diffstat (limited to 'bin/reproducible_html_breakages.py')
-rwxr-xr-xbin/reproducible_html_breakages.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_html_breakages.py b/bin/reproducible_html_breakages.py
index ca227504..929da615 100755
--- a/bin/reproducible_html_breakages.py
+++ b/bin/reproducible_html_breakages.py
@@ -109,12 +109,12 @@ def lack_buildinfo():
def pbuilder_dep_fail():
log.info('running pbuilder_dep_fail check...')
bad_pkgs = []
# we only care about these failures in the testing suite as they happen
# all the time in other suites, as packages are buggy
# and specific versions also come and go
query = '''SELECT s.name, r.version, s.suite, s.architecture
FROM sources AS s JOIN results AS r ON r.package_id=s.id
- WHERE r.status = 'FTBFS' AND s.suite = 'testing'
+ WHERE r.status = 'FTBFS' AND s.suite = 'stretch'
ORDER BY s.name ASC, s.suite DESC, s.architecture ASC'''
results = query_db(query)
for pkg, version, suite, arch in results:
@@ -109,12 +109,12 @@ def lack_buildinfo():
log.info('running pbuilder_dep_fail check...')
bad_pkgs = []
- # we only care about these failures in the testing suite as they happen
+ # we only care about these failures in the stretch suite as they happen
# all the time in other suites, as packages are buggy
# and specific versions also come and go